@@ -39,8 +39,18 @@ class Decompressor():
             await afp.write(await download_stream.readall())
 
     async def upload_decompressed_files(self, container_name, dest_dir, decompression_dir):
-        for file in os.listdir(decompression_dir):
-            await self.upload_decompressed_file("{}/{}".format(decompression_dir, file), container_name, dest_dir)        
+        files_to_upload = self.get_files_to_upload(decompression_dir)
+        for file in files_to_upload:
+            await self.upload_decompressed_file(file, container_name, dest_dir)      
+
+    def get_files_to_upload(self, decompression_dir):
+        files = []
+        # r=root, d=directories, f = files
+        for r, d, f in os.walk(decompression_dir):
+            for file in f:
+                files.append(os.path.join(r, file))
+
+        return files
 
     async def upload_decompressed_file(self, file, container_name, dest_dir):
         blob_service_client = BlobServiceClient.from_connection_string(self.conn_str)
